# ========TK_DRAFT=========

# Cronk: a cron-json translator

<!--
The standard commands for the Scorecard and Best Practices badges are:

    [![OpenSSF Scorecard](https://api.securityscorecards.dev/projects/github.com/nebraska-dev/cronk/badge)](https://api.securityscorecards.dev/projects/github.com/nebraska-dev/cronk)
    [![OpenSSF Best Practices](https://bestpractices.coreinfrastructure.org/projects/6829/badge)](https://bestpractices.coreinfrastructure.org/projects/6829)

However, the badges and links always show the project's current scores. In order to
display the correct scores at each blog post, we've therefore used files stored in the
docs/ folder.
-->
[![OpenSSF Scorecard](docs/scorecard_badge.png)](docs/scorecard.json)
[![OpenSSF Best Practices](docs/best_practices_badge.png)](https://htmlpreview.github.io/?https://github.com/nebraska-dev/cronk/blob/main/docs/BadgeApp.html)

---

_This repository is a part of the Google Open Source Blog's_
"[From zero to supply-chain security hero](TK_BLOG_SERIES_URL)" _blog series. It is
meant for demonstrative purposes, and should not be used in production!_

_All information beyond this point is fictional!_

---

- Student: Alice Doe (@nebraska-dev), 2018Q4
- Course: TK_FUNNY_COURSE_NAME_42 @ Cottonwood University (TK Cottonwood is the Nebraska state tree, and there is no such university)

Cronk allows developers to convert files between the crontab and json formats.

To-do:

- Add i18n of periodicity via Babel
